<p align="center">
  <img src="https://grayhat12.github.io/compiler/favicon_io/favicon-32x32.png" width="32" />
</p>
<div align="center">
  <a href="https://travis-ci.org/github/GrayHat12/garser">
    <img src="https://api.travis-ci.org/GrayHat12/garser.svg?branch=master&status=created" alt="Build Status" />
  </a>
  <a href="#">
    <img src="https://img.shields.io/badge/python-3.7-blue.svg?style=flat-square" alt="Python version" />
  </a>
  <a href="https://github.com/grayhat12/garser/blob/master/LICENSE">
    <img src="https://img.shields.io/github/license/grayhat12/garser.svg?style=flat-square" alt="License" />
  </a>
</div>

<h4 align="center">Wrapper around the HTMLParser python module</h4>

<p align="center">
  <a href="https://grayhat12.github.io/garser/">Documentation</a> •
  <a href="https://grayhat12.github.io/garser/usage/">Basic usage</a> •
</p>

## About

Garser is one of the more advanced tools to scan and parse html. It stores all html entities in objects

## Features

- Parses HTML in nested object format
- Attributes are stored as data members
- Nested and Non-Nested Entity search
- Entity Search based on attributes
- Intelligent nesting for non closing html entities
- Objects can be converted to JSON Format
- Inspired by Selenium


## License

This tool is licensed under the GNU General Public License v3.0.

Some parts of this code comes from [HTMLParser](https://docs.python.org/2/library/htmlparser.html)
